module.exports = Behavior({
  properties: {
    appId: {
      type: String,
      value: ''
    },
    identityId: {
      type: String,
      value: ''
    },
    show: {
      type: Boolean,
      value: false
    },
    baseUrl: {
      type: String,
      value: ''
    },
    tenantId : {
      type: String,
      value: ''
    }
  },
  data: {
    mode: "",
    userId: "admin",
    appType: "WECHAT",
    identityType: "applet-wechat",
    reportApiPath: "",
    language: "SIMPLIFIED_CHINESE",
    baseUrl: "https://cpm-api.convertlab.com",
    centerUrlPath: "/sdkApi/miniProgram/center",
    popupUrlPath: "/sdkApi/miniProgram/popup",
    theme: {},
    privacyList:[],
    linkContent:"",
    purposeList:[],
    purposeStatus: {},
    linkList: [],
    location: "",
    enable: false,
    seen: false,
    requestConfig: false,
    onConfirm:null,
    onRefuse:null,
    onLoad:null
  },
  lifetimes: {

    attached: function () {
      const initData = {};
      if(this.properties.appId && this.properties.appId.length > 0) {
        initData.appId = this.properties.appId
      }
      if(this.properties.identityId && this.properties.identityId.length > 0) {
        initData.identityId = this.properties.identityId
      }
      if(this.properties.tenantId && this.properties.tenantId.length > 0) {
        initData.tenantId = this.properties.tenantId
      }
      if(typeof this.properties.show === 'boolean') {
        initData.show = this.properties.show
      }
      if(this.properties.baseUrl && this.properties.baseUrl.length > 0) {
        initData.baseUrl = this.properties.baseUrl
      }

      const pages = getCurrentPages();
      if (pages && pages.length > 0) {
        const currentPage = pages[pages.length - 1]
        if (currentPage && currentPage.route) {
          initData.location = currentPage.route;
        }
      }
      if(typeof this.data.appId !== "string" || this.data.appId.length === 0){
      const appInfo = wx.getAppBaseInfo && wx.getAppBaseInfo();
      const accountInfo = wx.getAccountInfoSync && wx.getAccountInfoSync();
      if (appInfo && appInfo.host && appInfo.host.appId) {
        initData.appId = appInfo.host.appId;
      } else if(accountInfo && accountInfo.miniProgram && accountInfo.miniProgram.appId){
        initData.appId = accountInfo.miniProgram.appId;
      } else {
        wx.getSystemInfo({
          success(result) {
            if (result && result.host && result.host.appId) {
              initData.appId = result.host.appId;
            }
          },
        })
      }
      }
      Object.assign(this.data, initData)
      // this.setData(initData)

    }
  },

  methods: {
    resovlePrivacyList(data) {
      const privacyList = [];
      if (data &&
        data.document &&
        data.document.documentVoList &&
        data.document.documentVoList.length > 0) {
        for (var index in data.document.documentVoList) {
          const document = data.document.documentVoList[index];
          if (document) {
            privacyList.push(document);
          }
        }
      }
      return privacyList;
    },

    resolvePurposeList(data) {
      const purposeList = [];
      if (data &&
        data.purposeList &&
        data.purposeList &&
        data.purposeList.length > 0) {
        for (var index in data.purposeList) {
          const purposeItem = data.purposeList[index];
          if (purposeItem) {
            purposeList.push(purposeItem);
          }
        }
      }
      return purposeList;
    },

    buildPrivacyLinksContent(privacyList, language, themeColor) {
      var buildContent = '';
      if(privacyList && privacyList.length > 0) {
        var appendCounter=0;
        for(var index in privacyList) {
          const privacyItem = privacyList[index];
          if(privacyItem && typeof privacyItem.name  === 'string' && privacyItem.name.length > 0) {
            const isChiness = language === 'SIMPLIFIED_CHINESE' || language === 'TRADITIONAL_CHINESE';
            if(appendCounter > 0) {
              buildContent += " "
            }
            const startFlag = isChiness?'《':'<i>';
            const endFlag = isChiness?'》':'</i>';

            var applyFlag = privacyItem.name.indexOf(startFlag) !== 0

            var segment = ""
            if(applyFlag) {
              segment +=  startFlag
            }
            segment += privacyItem.name;
            if(applyFlag) {
              segment += endFlag
            }
            buildContent += '<a href="' + privacyItem.documentUrl + '">' + segment + "</a>";
            appendCounter++;
          }
        }
      }
      if(buildContent && buildContent.length > 0) {

        buildContent = '<br/><br/><div style="font-size: 11px;color: #0000FF"' 
        // + ((typeof themeColor === 'string' && themeColor.length > 0)?('color:\'' + themeColor + '\';"'):'"')
          + '>'  + buildContent + '</div>';
      }
      return buildContent;
    },

    queryPurposeStatus(callback) {
      if (this.data.baseUrl && this.data.baseUrl.indexOf('http') >= 0) {
        wx.request({
          url: this.data.baseUrl + this.data.reportApiPath + "?identityType=" + this.data.identityType + "&identityId=" + this.data.identityId + "&appType=" + this.data.appType + "&location=" + this.data.location + "&appId=" + this.data.appId,
          method: "GET",
          header: {
            "Accept": "application/json",
            "Content-Type": "application/json;charset=utf-8",
            "x-tenant-id": this.data.tenantId,
            "x_user_id": this.data.userId
          },
          success: (data) => {
            if (data && data.data && data.data.length > 0) {
              const purposeStatusList = this.data.purposeStatus;
              const records  = data.data;
              for (var index in records) {
                const item = records[index];
                if (item && item.purposeCode) {
                  purposeStatusList[item.purposeCode] = {
                    purposeCode: item.purposeCode,
                    status: item.status,
                    checked: ('OPT_IN' === item.status) ? true : false
                  };

                }
              }
              this.setData({
                purposeStatus: purposeStatusList
              });
            }

            if (callback && callback.success) {
              
              callback.success(this.createPurposeStatusSnapshot());
            }
          },
          fail: (err) => {
            if (callback && callback.error) {
              callback.error(err);
            }
          }
        })

      }
    },

    requestAppConfig(callback) {
      if (this.data.baseUrl && this.data.baseUrl.indexOf('http') >= 0) {
        wx.request({
          url: this.data.baseUrl + "/sdkApi/miniProgram/config?appType=" + this.data.appType + "&appId=" + this.data.appId,
          method: "GET",
          header: {
            "Accept": "application/json",
            "Content-Type": "application/json;charset=utf-8",
            "x-tenant-id": this.data.tenantId,
            "x_user_id": this.data.userId
          },
          success: function (response) {
            if(!response || response.statusCode !== 200) {
              if (callback && typeof callback.fail === "function") {
                callback.fail(err);
              }
              return
            }
            const data = response.data;
            const componentCfg = this.data.mode === "dialog"?data.privacyPopup:data.privacyCenter;
            const reportApiPath = this.data.mode === "dialog"?this.data.popupUrlPath:this.data.centerUrlPath;
            const language = (componentCfg &&
              componentCfg.language) ||  this.data.language;

            var privacyList;
            var purposeList;
            if (componentCfg &&
              componentCfg.collectionPoint) {
                privacyList = this.resovlePrivacyList(componentCfg.collectionPoint);
                purposeList = this.resolvePurposeList(componentCfg.collectionPoint);
            }

            const linkContent = this.buildPrivacyLinksContent(privacyList, language);
         
            if(privacyList && privacyList.length > 0) {

            }
       

            const theme = {};
            if (data.privacyCenter) {
              theme.center = {
                language: data.privacyCenter.language,
                color: data.privacyCenter.color,
                law: data.privacyCenter.law,
                description: data.privacyCenter.description,
                title: data.privacyCenter.title,
                content: data.privacyCenter.content,
                documentIsInBottom: data.privacyCenter.documentIsInBottom,
                backgroundColor: data.privacyCenter.backgroundColor,
                fontColor: data.privacyCenter.fontColor,
                saveButtonText: data.privacyCenter.saveButtonText,
                saveButtonFontColor: data.privacyCenter.saveButtonFontColor,
                saveButtonBackgroundColor: data.privacyCenter.saveButtonBackgroundColor
              }
            } else {
              theme.center = {}
            }

            if (data.privacyPopup) {
              theme.popup = {
                language: data.privacyPopup.language,
                color: data.privacyPopup.color,
                law: data.privacyPopup.law,
                description: data.privacyPopup.description,
                title: data.privacyPopup.title,
                content: data.privacyPopup.content,
                documentIsInBottom: data.privacyPopup.documentIsInBottom,
                documentFontColor: data.privacyPopup.documentFontColor,
                backgroundColor: data.privacyPopup.backgroundColor,
                fontColor: data.privacyPopup.fontColor,
                agreeButtonText: data.privacyPopup.agreeButtonText,
                agreeButtonFontColor: data.privacyPopup.agreeButtonFontColor,
                agreeButtonBackgroundColor: data.privacyPopup.agreeButtonBackgroundColor,
                refuseButtonText: data.privacyPopup.refuseButtonText,
                refuseButtonFontColor: data.privacyPopup.refuseButtonFontColor,
                refuseButtonBackgroundColor: data.privacyPopup.refuseButtonBackgroundColor
              }

              
            } else {
              theme.popup = {}
            }

            this.setData({
              theme: theme,
              privacyList: privacyList,
              purposeList: purposeList,
              reportApiPath: reportApiPath,
              linkList: privacyList,
              linkContent: linkContent,
              language: language
            })

            if (callback && typeof callback.success === "function") {
              callback.success.bind(this);
              callback.success({
                theme: theme,
                purposeList: purposeList,
                linkList: privacyList
              });
            }



          }.bind(this),
          fail: function (err) {
            if (callback && typeof callback.fail === "function") {
              callback.fail(err);
            }
          }.bind(this)
        })

      }
    },

    createPurposeStatusSnapshot() {
      const purposeStatusList = this.data.purposeStatus;
      const purposeList = this.data.purposeList;
      const purposeSnapshotList =[];
      if (purposeList && purposeStatusList) {
        for (var index in purposeList) {
          const purposeItem = purposeList[index];
          if (purposeItem && purposeItem.code) {
            const purposeStatus = purposeStatusList[purposeItem.code];
            const hasStatus = purposeStatus && purposeStatus.status && purposeStatus.status.length > 0;
            purposeSnapshotList.push({
              consentId: purposeItem.id,
              purposeCode: purposeItem.code,
              purposeStatus: (hasStatus && purposeStatus.status) || 'OPT_OUT',
              name: purposeItem.name,
              documentName: purposeItem.documentName,
              showName: purposeItem.showName,
              purposeName: purposeItem.consentItem,
              status: hasStatus && 'OPT_IN' === purposeStatus.status
            })         
          }
        }
      }
      return purposeSnapshotList
    },
  
    setPurposeStatus(selected, code) {
      const purposeStatusList = this.data.purposeStatus || [];
      if (code) {
        purposeStatusList[code] = {
          consentId: code,
          purposeCode: code,
          status: selected ? 'OPT_IN' : 'OPT_OUT',
          checked: selected
        };
        this.setData({
          purposeStatus: purposeStatusList
        })
      } else {
        const purposeList = this.data.purposeList;
        if (purposeList) {
          for (var index in purposeList) {
            const purposeItem = purposeList[index];
            if (purposeItem && purposeItem.code) {
              purposeStatusList[purposeItem.code] = {
                consentId: purposeItem.code,
                purposeCode: purposeItem.code,
                status: selected ? 'OPT_IN' : 'OPT_OUT',
                checked: selected
              };
            }
          }
          this.setData({
            purposeStatus: purposeStatusList
          })
        }
      }
    
    },
    reportSeenPurposeStatus: function (callback) {
      if (this.data.baseUrl && this.data.baseUrl.indexOf('http') >= 0) {
        const purposeList = this.data.purposeList;
        const purposeStatusList = this.data.purposeStatus;
        const requestBody = [];
        if (purposeList && purposeStatusList) {
          for (var index in purposeList) {
            const purposeItem = purposeList[index];
            if (purposeItem &&
              purposeItem.purposeCode) {
              const purposeStatus = purposeStatusList[purposeItem.purposeCode];
              if(!purposeStatus || !purposeStatus.status) {
                requestBody.push({
                  consentId: purposeItem.id,
                  purposeCode: purposeItem.purposeCode,
                  status: 'SEEN'
                })
              }
            }
          }
        }
        if(requestBody.length > 0) {
          this.report({
            url: this.data.baseUrl + this.data.reportApiPath,
            body: requestBody,
            success: callback.success,
            fail: callback.fail
          });
        }
     
      }
    },

   
    report(requestOptions) {
      if (requestOptions.url) {
        const statusSnapshotList = this.createPurposeStatusSnapshot();
        var requestBody = requestOptions.body;
        if(!requestBody && statusSnapshotList) {
          requestBody = [];
          for(var index in statusSnapshotList) {
            const statusSnapshot = statusSnapshotList[index]
            requestBody.push({
              purposeCode: statusSnapshot.purposeCode,
              status:  statusSnapshot.purposeStatus
            })
          }
        }
        const snapshotList = requestOptions && requestOptions.body ? [] : statusSnapshotList;

        if(requestBody && requestBody.length > 0) {
          const bodyWrapper = {
            identityId: this.data.identityId,
            identityType: this.data.identityType,
            appId: this.data.appId,
            appType: this.data.appType,
            location: this.data.location,
            dataList: requestBody
          }
          
          wx.request({
            url: requestOptions.url,
            method: "POST",
            data: bodyWrapper,
            header: {
              "Accept": "application/json",
              "Content-Type": "application/json;charset=utf-8",
              "x-tenant-id": this.data.tenantId,
              "x_user_id": this.data.userId
            },
            success: (data) => {
              if (data && data.data && data.data.status && data.data.status === 200) {
                if (requestOptions && requestOptions.success) {
                  requestOptions.success(data);
                }
              } else if (data && data.errMsg && data.errMsg.length > 0) {
                if (requestOptions && requestOptions.fail) {
                  requestOptions.fail(data.errMsg);
                }
  
              } else {
                if (requestOptions && requestOptions.fail) {
                  requestOptions.fail("unknown error");
                }
              }
            },
            fail: (err) => {
              if (requestOptions && requestOptions.fail) {
                requestOptions.fail(err);
              }
            }
          })
        }
     
   
        return snapshotList;
      }
    },

    reportPurposeStatus(requestOptions){
      this.report(requestOptions?requestOptions:{
        url: this.data.baseUrl + this.data.reportApiPath
      });
    },
  }
})