const common = require('../../business');

Component({
  behaviors: [common],
  data: {
    mode: "dialog"
  },
  properties: {
    appId: {
      type: String,
      value: ''
    },
    openId: {
      type: String,
      value: ''
    },
    closeOnClickModal: {
      type: Boolean,
      value: true
    }
  },

  methods: {
    onClose: function name(event) {
      this.setData({
        show: false
      });
    },
    onOpenUrl: function name(event) {
      this.triggerEvent('openurl', event.detail)
    },
    onButtonAgree: function(event) {
      this.setPurposeStatus(true)
      this.reportPurposeStatus();
      if(typeof this.data.onConfirm !== "function" || this.data.onConfirm() !== true) {
        this.setData({
          show: false
        });
      } 
      this.triggerEvent('confirm', {statusList: this.createPurposeStatusSnapshot()});
    },
    onButtonRefuse: function(event) {
      this.setPurposeStatus(false)
      this.reportPurposeStatus();
      if(typeof this.data.onRefuse !== "function" || this.data.onRefuse() !== true) {
        this.setData({
          show: false
        });
      } 
      this.triggerEvent('refuse', {statusList: this.createPurposeStatusSnapshot()});

    },
    requestConfig: function() {
      if(!this.data.requestConfig && this.data.identityId && this.data.appId) {
        this.data.requestConfig = true;
        if (!this.data.enable) {
          
          this.requestAppConfig({
            success: function(data) {
              this.queryPurposeStatus({
                success: (data) => {
                  
                  this.setData({
                    enable: true,
                    requestConfig: false
                  })


                  var eventData = {
                    statusList: []
                  }
                  if( this.data.theme &&  this.data.theme.popup) {
                    eventData.title = this.data.theme.popup.title
                    eventData.content =  this.data.theme.popup.content
                  }
               
                  var purposeAgreeCounter = 0;
                  eventData.statusList = data;
                  if(data && data.length > 0) {
                    for(var index in data) {
                      const purposeStatus = data[index];
                      if(purposeStatus && purposeStatus.status === 'OPT_IN') {
                        purposeAgreeCounter ++
                      }
                    }   
                  } 

                  eventData.allAgree = purposeAgreeCounter > 0 && purposeAgreeCounter === eventData.statusList.length;
                 

                  this.triggerEvent('load', data)

                  if(typeof this.data.onLoad === "function") {
                    this.data.onLoad(eventData)
                  } 
                },
                fail: (err) => {
                  this.setData({
                    enable: false,
                    requestConfig: false
  
                  })
                }
              });
            }.bind(this)
          });
        }
      }
    },  
  },

  observers: {
    'show': function(value) {
      if(value && !this.data.seen) {
        this.reportSeenPurposeStatus({
          success() {
            this.data.seen = true;
          }
        });
      }
    },
    'appId': function(value) {
      this.requestConfig();
    },
    'identityId': function(value) {
      this.requestConfig();
    }
  }
})